@@ -14,12 +14,15 @@ plt.rc('font', family='serif')
 from sklearn import decomposition
 from sklearn.preprocessing import MinMaxScaler
 from sklearn.ensemble import RandomForestClassifier
+from sklearn.neural_network import MLPClassifier
 from sklearn.metrics import confusion_matrix, auc, RocCurveDisplay
 from sklearn.model_selection import KFold, StratifiedKFold
 from sklearn.manifold import TSNE
 from xgboost import XGBClassifier
 
-def create(data_x, data_y, clf='rf', impute=True, optimize=True, imp_method='MissForest', n_iter=25):
+from pyBIA.optimization import KNN_imputation, MissForest_imputation, boruta_opt, hyper_opt
+
+def create(data_x, data_y, clf='rf', impute=True, optimize=True, imp_method='KNN', n_iter=25):
     """Creates the Random Forest model and PCA transformation used for classification.
     
     Example:
@@ -71,6 +74,19 @@ def create(data_x, data_y, clf='rf', impute=True, optimize=True, imp_method='Mis
         model = MLPClassifier()
     elif clf == 'xgb':
         model = XGBClassifier()
+        if all(isinstance(val, (int, str)) for val in data_y):
+            print('XGBoost classifier requires numerical class labels! Converting class labels as follows:')
+            print('________________________________')
+            y = np.zeros(len(data_y))
+            for i in range(len(np.unique(data_y))):
+                print('{} -----------> {}'.format(np.unique(data_y)[i], i))
+                index = np.where(data_y == np.unique(data_y)[i])[0]
+                y[index] = i
+            data_y = y 
+            print('--------------------------------')
+
+    else:
+        raise ValueError('clf argument must either be "rf", "nn", or "xgb".')
     
     if impute is False and optimize is False:
         print("Returning base model...")
@@ -93,7 +109,6 @@ def create(data_x, data_y, clf='rf', impute=True, optimize=True, imp_method='Mis
 
     features_index = boruta_opt(data_x, data_y)
     model, best_params = hyper_opt(data_x[:,features_index], data_y, clf=clf, n_iter=n_iter)
-    print('Hyperparameter optimization complete!')
     model.fit(data_x[:,features_index], data_y)
 
     return model, imputer, features_index
